api.events.v1.test_helpers.aggregated package — Argus-Toolbelt 1.0 documentation

# api.events.v1.test_helpers.aggregated package

## Submodules

## api.events.v1.test_helpers.aggregated.find_aggregated_event_stats module

`api.events.v1.test_helpers.aggregated.find_aggregated_event_stats.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/aggregated/stats, respond with HTTP 403

`api.events.v1.test_helpers.aggregated.find_aggregated_event_stats.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/aggregated/stats, respond with HTTP 404

`api.events.v1.test_helpers.aggregated.find_aggregated_event_stats.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/aggregated/stats, respond with HTTP 200

`api.events.v1.test_helpers.aggregated.find_aggregated_event_stats.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/aggregated/stats, respond with HTTP 401

## api.events.v1.test_helpers.aggregated.find_aggregated_events module

`api.events.v1.test_helpers.aggregated.find_aggregated_events.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/aggregated/search, respond with HTTP 403

`api.events.v1.test_helpers.aggregated.find_aggregated_events.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/aggregated/search, respond with HTTP 404

`api.events.v1.test_helpers.aggregated.find_aggregated_events.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/aggregated/search, respond with HTTP 200

`api.events.v1.test_helpers.aggregated.find_aggregated_events.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/aggregated/search, respond with HTTP 401

## api.events.v1.test_helpers.aggregated.list_aggregated_events module

`api.events.v1.test_helpers.aggregated.list_aggregated_events.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/aggregated, respond with HTTP 403

`api.events.v1.test_helpers.aggregated.list_aggregated_events.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/aggregated, respond with HTTP 404

`api.events.v1.test_helpers.aggregated.list_aggregated_events.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/aggregated, respond with HTTP 200

`api.events.v1.test_helpers.aggregated.list_aggregated_events.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/aggregated, respond with HTTP 401

## Module contents